% -------------------------------------------------------------------
% demo.m
% 
% Demonstrate the Riesz-Wavelet Pyramid
% -------------------------------------------------------------------
%
% Dimitri Van De Ville, Michael Unser
% Ecole Polytechnique Federale de Lausanne
%
% -------------------------------------------------------------------
%
% REFERENCE:
% M. Unser, D. Van De Ville, 
%   "Steerable wavelet frames and pyramid in L2(Rd)," submitted
%
% -------------------------------------------------------------------

% Read data
A=double(imread('cameraman.tif'));
%A=double(imread('fingerprint.jpg'));
%A=double(imread('denoising/fundus256.gif'));
%A=imresize(A,[4 4]);
%A=randn(256,256);

% Setup parameters
clear config;
config.size=size(A);      % size of data
config.datatype='real';   % 'real', 'complex'
config.type='ortho'; % 'bspline', 'dual', 'ortho', 'Simoncelli' (for B-spline: at synthesis side)
config.Simoncelli.initial=false; % perform initial high-pass filter or not
config.alpha=1;           % degree of B-spline pyramid (integer)
config.N=2;               % order of the Riesz transform
config.prefilter.type='bandlimited'; % 'bandlimited', 'none'

% Precompute filters
config=RieszPrepareTransform(config);
if ~config.ready,
    disp('Riesz-Pyramid decomposition not ready!');
    break;
end;

% Prefilter (projection into initial approximation space V0)
PA=RieszPrefilter(A,config);

% number of decomposition levels
J=4;

% Analysis step
Q=RieszAnalysis(PA,config,J);

%Q{1}(:,:,1)=0*Q{1}(:,:,1);
%Q{1}(:,:,2)=1.48*Q{1}(:,:,2);
%Q{1}(:,:,3)=0*Q{1}(:,:,3);
%config.riesz.filter(1,1,:)=0;

% Visualize decomposition
figure;
RieszVisualize(Q,config,J);

% Synthesis step
PR=RieszSynthesis(Q,config,J);

% Postfilter
R=RieszPostfilter(PR,config);

figure;
imshow(R,[]);

% Check for perfect reconstruction
fprintf('Maximum absolute value reconstruction error: %e\n',max(abs(double(A(:))-R(:))));
fprintf('Root mean square error: %e\n',sqrt(mean(abs(double(A(:))-R(:)).^2)));
